package com.yx.face.service.impl;

import com.alibaba.fastjson.JSON;
import com.yx.face.model.dto.UavDTO;
import com.yx.face.model.dto.UavDecDTO;
import com.yx.face.model.dto.UavEcnDTO;
import com.yx.face.model.entity.*;
import com.yx.face.service.UavService;
import com.yx.face.utils.RsaUtil;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.*;

/**
 * @description: FaceServiceImpl <br>
 * @date: 2021/6/2 14:49 <br>
 * @author: PWB <br>
 */

@Slf4j
@Service
public class UavServiceImpl implements UavService {


    @Resource
    private UavIServiceImpl service;

    @Value("${uav.apiKey}")
    private String apiKey;

    @Value("${uav.privateKey}")
    private String privateKey;

    @Override
    public Boolean add(UavEcnDTO dto) {

        String apiKey = dto.getApiKey();
        log.info("请求apiKey:{}",apiKey);
        if (!apiKey.equals(this.apiKey)){
            log.info("apiKey不匹配");
            throw new RuntimeException("apiKey不匹配");
        }

        String content = dto.getContent();
        String decJson ="";
        try {
            decJson = RsaUtil.decryptByPrivateKey(content, privateKey);
        } catch (Exception e) {
            log.info("无人机推送数据解密失败！");
            throw new RuntimeException("数据解密失败，请检查数据是否正确！");
        }

        UavDecDTO uavDecDTO = JSON.parseObject(decJson, UavDecDTO.class);
        log.info("无人机数据接收：{}", JSON.toJSONString(uavDecDTO));

        List<UavDTO> objects = uavDecDTO.getObjects();
        ArrayList<Uav> uavList = new ArrayList<>();
        for (UavDTO uavDTO : objects) {
            Uav uav = new Uav();
            uav.setObjectId(uavDTO.getObjectId());
            uav.setLongitude(uavDTO.getLongitude());
            uav.setLatitude(uavDTO.getLatitude());
            uav.setAltitude(uavDTO.getAltitude());
            uav.setHeight(uavDTO.getHeight());
            uav.setSpeed(uavDTO.getSpeed());
            uav.setTime(uavDTO.getTime());
            uav.setLocation(uavDTO.getLocation());
            uav.setUavModel(uavDTO.getUavModel());
            uav.setUavSN(uavDTO.getUavSN());
            uav.setChannel(uavDTO.getChannel());
            uav.setDeviceType(uavDTO.getDeviceType());
            uavList.add(uav);
        }

        boolean b = service.saveBatch(uavList);
        return b;
    }

}
