package com.yx.face.utils;

import cn.hutool.core.util.CharsetUtil;
import cn.hutool.core.util.HexUtil;
import cn.hutool.crypto.Mode;
import cn.hutool.crypto.Padding;
import cn.hutool.crypto.SmUtil;
import cn.hutool.crypto.symmetric.SM4;

import javax.crypto.SecretKey;

/**
 * SM4加解密工具类
 * @Author lsh
 * @date 2024/12/13
 */
public class Sm4Util {

    /**
     * 获取sm4秘钥
     *
     * @return sm4秘钥
     */
    public static String getSm4Key() {
        SM4 sm4 = SmUtil.sm4();
        SecretKey secretKey = sm4.getSecretKey();
        byte[] encoded = secretKey.getEncoded();
        return HexUtil.encodeHexStr(encoded);
    }

    /**
     * sm4加密 key长度32位字符
     *
     * @param content 文本
     * @param sm4Key  sm4秘钥
     * @return 加密后的结果
     */
    public static String encrypt(String content, String sm4Key) {
        SM4 sm4 = new SM4(HexUtil.decodeHex(sm4Key));
        return sm4.encryptHex(content);
    }

    /**
     * sm4解密 key长度32位字符
     * @param content
     * @param sm4Key
     * @return 解密后的结果
     */
    public static String decrypt(String content, String sm4Key) {
        SM4 sm4 = new SM4(HexUtil.decodeHex(sm4Key));
        return sm4.decryptStr(content);
    }


    /**
     * sm4 16进制key加密 key长度16位字符
     *
     * @param content 文本
     * @param sm4Key  sm4秘钥
     * @return 加密后的结果
     */
    public static String encryptByHexKey(String content, String sm4Key) {
        SM4 sm4 = new SM4(Mode.ECB, Padding.PKCS5Padding, sm4Key.getBytes());
        byte[] encrypt = sm4.encrypt(content);
        return HexUtil.encodeHexStr(encrypt);
    }


    /**
     * sm4 16进制key解密 key长度16位字符
     * @param content
     * @param sm4Key
     * @return 解密后的结果
     */
    public static String decryptByHexKey(String content, String sm4Key) {
        SM4 sm4 = new SM4(Mode.ECB, Padding.PKCS5Padding, sm4Key.getBytes());
        return sm4.decryptStr(content, CharsetUtil.CHARSET_UTF_8);
    }

}
